@@ -1,6 +1,5 @@
 from copy import copy, deepcopy
 from inspect import Parameter, Signature
-from pathlib import Path
 from typing import *
 
 from .accessor import Accessor
@@ -68,7 +67,7 @@ class DataMetaclass(type):
 
         def __init__(self, *args, **kwargs):
             for key, val in kwargs.items():
-                if key in keys:
+                if key in get_fields_info(self.__class__):
                     setattr(self, key, val)
 
             if hasattr(self, "__build__"):
@@ -80,7 +79,7 @@ class DataMetaclass(type):
             result = cls.__new__(cls)
             result.__dict__.update(self.__dict__)
 
-            for key in keys:
+            for key in get_fields_info(cls):
                 val = getattr(self, key)
                 setattr(result, key, copy(val))
 
@@ -94,19 +93,19 @@ class DataMetaclass(type):
             for k, v in self.__dict__.items():
                 setattr(result, k, deepcopy(v, memo))
 
-            for key in keys:
+            for key in get_fields_info(cls):
                 val = getattr(self, key)
                 setattr(result, key, deepcopy(val))
 
             return result
 
         def __iter__(self):
-            for key in keys:
+            for key in get_fields_info(self.__class__):
                 yield key, getattr(self, key)
 
         def __repr__(self):
             components = []
-            for key in keys:
+            for key in get_fields_info(self.__class__):
                 val = getattr(self, key)
                 if isinstance(val, str):
                     components.append(f'{key}="{val}"')
@@ -127,8 +126,12 @@ class DataMetaclass(type):
 
         cls = super().__new__(cls, name, bases, data)
         fields_info = get_fields_info(cls)
-        fields_info.update(fields)
 
+        for base in bases[::-1]:
+            if issubclass(base, Dataclass):
+                fields_info.update(get_fields_info(base))
+
+        fields_info.update(fields)
         return cls
 
 
